@@ -147,18 +147,6 @@ def lookahead(parser: Parser) -> Parser:
     return lookahead_parser
 
 
-def transform(parser: Parser, function: Callable[[Any], Any]) -> Parser:
-    @Parser
-    def transform_parser(stream: str, pos: int) -> Result:
-        result = parser(stream, pos)
-        if result:
-            return Success(pos, result.end, function(result.value))
-        else:
-            return result  # Failure
-
-    return transform_parser
-
-
 def negate(parser: Parser) -> Parser:
     @Parser
     def negate_parser(stream: str, pos: int) -> Result:
@@ -171,13 +159,25 @@ def negate(parser: Parser) -> Parser:
     return negate_parser
 
 
+def map(parser: Parser, function: Callable[[Any], Any]) -> Parser:
+    @Parser
+    def map_parser(stream: str, pos: int) -> Result:
+        result = parser(stream, pos)
+        if result:
+            return Success(pos, result.end, function(result.value))
+        else:
+            return result  # Failure
+
+    return map_parser
+
+
 def combine(parser: Parser, delimiter: str = "") -> Parser:
-    return transform(parser, lambda items: delimiter.join(utils.stringify(utils.filter(utils.flatten(items)))))
+    return map(parser, lambda items: delimiter.join(utils.stringify(utils.filter(utils.flatten(items)))))
 
 
 def flatten(parser: Parser) -> Parser:
-    return transform(parser, lambda items: [*utils.flatten(items)])
+    return map(parser, lambda items: [*utils.flatten(items)])
 
 
 def filter(parser: Parser) -> Parser:
-    return transform(parser, lambda items: [*utils.filter(items)])
+    return map(parser, lambda items: [*utils.filter(items)])
